@@ -7,7 +7,7 @@ technically possible, to reduce locations where this data has to be
 maintained redundantly.
 """
 
-version = '1.1'
+version = '1.2.1'
 author = u'Jyrki Pulliainen'
-author_email = 'jyrki@spotify.com'
+author_email = 'jyrki@dywypi.org'
 url = 'https://github.com/spotify/dh-virtualenv'
